#### 简要描述：
- 监管启动分析：运单开始进行启动分析，监控车辆状态（车开出起点围栏则变为已发车）
- 启动监管：车次派发后，开始启动监管分析，即运单状态直接变为已发车
- 结束监管：结束启动监管分析，即运单状态直接变为已结束
#### 接口版本：
|版本号|制定人|制定日期|修订日期|
|:----    |:---|:----- |-----   |
|1.0.0 |lenny  |2022-10-14 |  2020-10-14 |

#### 请求URL:

- 国际客户：http://icloud.assetscontrols.com:8092/OpenApi/Admin
- 国内客户：http://cloud.assetscontrols.com:8092/OpenApi/Admin

#### 请求方式：

- POST
#### 请求头：

|参数名|是否必须|类型|说明|
|:----    |:---|:----- |-----   |
|Content-Type |是  |string |请求类型： application/json   |

#### 请求参数:

|参数名|是否必须|类型|说明|
|:----    |:---|:----- |-----   |
|FTokenID |是  |string |令牌ID   |
|FAction |是  |string |方法名 (SendCommandToRouteAnalysis )   |
|FAssetID |是|string |  设备号|
|FType |是  | int | 0：监管启动分析 1：启动监管  2：结束监管  |


#### 返回示例:

**正确时返回:**

```xml
{
    "Result": 200,
    "Message":"success",
    "FObject": null
}
```

**错误时返回:**

```xml
//表示传入的参数有问题
{
    "Result": 102,
    "Message": "param is error",
    "FObject": null
}
//表示有异常报错,参数条件不同，message也会不同
{
    "Result": 105,
    "Message": "start analysis task fail" / "start analysis fail" / "check fail",
    "FObject": null
}
//表示找不到此设备
{
    "Result": 106,
    "Message": "device does not exist",
    "FObject": null
}
//表示找不到设备相关联的运单
{
    "Result": 121,
    "Message": "no task found",
    "FObject": null
}

//表示已启动分析或者启动监管，无需再次启动
{
    "Result": 135,
    "Message": "task started" ,
    "FObject": null
}
//表示分析中找不到此任务，需要等待分析程序初始化
{
    "Result": 134,
    "Message": "task is being initialized",
    "FObject": null
}

//表示启动监管前需要启动分析
{
    "Result": 136,
    "Message": "analysis task is not started"  ，
    "FObject": null
} 
```

 
#### 备注:
- 更多返回错误代码如下：
- 106：账户过期
- 103：用户名或者密码错误
- 102：请求参数错误
- 105：表示有异常报错
- 106：表示找不到此设备号
- 121：表示找不到设备相关联的运单
- 134：表示分析中找不到此任务，需要等待分析程序初始化
- 135：表示已启动分析或者启动监管，无需再次启动
- 136：表示启动监管前需要启动分析

#### 请求示例:

**Java:**
```
String result = "";
//请求路径
String url = "http://cloud.assetscontrols.com:8092/OpenApi/Admin";  
//请求参数 ,json格式参数，建议用对象传入
String body = "{FAction:\"SendCommandToRouteAnalysis\",FTokenID:\"3acef045-d302-4032-b40a-d9ee6c1519cd\",FAssetID:\"13301781203\",FType: 0}";
URL realUrl = new URL(url);
// 设置通用请求的属性
URLConnection conn = realUrl.openConnection(); 
conn.setRequestProperty("accept", "*/*");
conn.setRequestProperty("connection", "keep-Alive");
conn.setRequestProperty("Content-Type", "application/json");
conn.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
conn.setRequestProperty("method", "post");
// 发送POST请求必须设置如下两行
conn.setDoOutput(true);
conn.setDoInput(true);
PrintWriter pw = new PrintWriter(conn.getOutputStream());
// 发送请求参数
pw.print(body);
// flush输出流的缓冲  
pw.flush();   
// 定义BufferedReader输入流来读取URL的响应
BufferedReader bufReader = new BufferedReader(new InputStreamReader(conn.getInputStream()));  
// 定义BufferedReader输入流来读取URL的响应
String line;
while ((line = bufReader.readLine()) != null) {
     result += line;        
 }
//返回的是json字符串
return result;
```

**C#：**
```
//请求路径
string url = "http://cloud.assetscontrols.com:8092/OpenApi/Admin";  
//请求参数 ,json格式参数，建议用对象传入
string body = "{FAction:\"SendCommandToRouteAnalysis\",FTokenID:\"3acef045-d302-4032-b40a-d9ee6c1519cd\",FAssetID:\"13301781203\",FType: 0}"; 
Encoding encoding = Encoding.UTF8;
HttpWebRequest request = (HttpWebRequest)WebRequest.Create(url);
 //请求方式 post / get
request.Method = "post"; 
request.Accept = "*/*";    
request.ContentType = "application/json";
request.UserAgent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)";
byte[] buffer = encoding.GetBytes(body);
request.ContentLength = buffer.Length;
request.GetRequestStream().Write(buffer, 0, buffer.Length);
HttpWebResponse response = (HttpWebResponse)request.GetResponse();
using (StreamReader reader = new StreamReader(response.GetResponseStream(), Encoding.UTF8))
{
	//返回的是json字符串
    return reader.ReadToEnd();
}
```

**Python：**
```python
url = 'http://cloud.assetscontrols.com:8092/OpenApi/Admin'
      data = {
      'FAction': 'SendCommandToRouteAnalysis',
      'FTokenID': '3acef045-d302-4032-b40a-d9ee6c1519cd', 
	  'FAssetID':'13301781203',
	  'FType':'0',
       }
      data = parse.urlencode(data).encode('utf-8')
      headers = {
       'User-Agent': r'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) '
                     r'Chrome/45.0.2454.85 Safari/537.36 115Browser/6.0.3',
       'Connection': 'keep-alive'
       }
      req = request.Request(url, headers=headers, data=data)  
      page = request.urlopen(req).read()
      page = page.decode('utf-8')
      # json_array = json.loads(page)
      return page;
```